@@ -17,10 +17,13 @@
 
 __visible extern int sys_getattr(const char *path, struct stat *sb);
 __visible extern int sys_readdir(const char *path, void *buf, fuse_fill_dir_t filler, off_t offset, struct fuse_file_info *fi);
+__visible extern int sys_readlink(const char *path, char *buf, size_t size);
 __visible extern int sys_release(const char *path, struct fuse_file_info *fi);
 __visible extern int sys_releasedir(const char *path, struct fuse_file_info *fi);
 __visible extern int sys_open(const char *path, struct fuse_file_info *fi);
+__visible extern int sys_opendir(const char *path, struct fuse_file_info *fi);
 __visible extern int sys_read(const char *path, char *buf, size_t size, off_t offset, struct fuse_file_info *fi);
+__visible extern int sys_write(const char *path, const char *buf, size_t size, off_t offset, struct fuse_file_info *fi);
 __visible extern int sys_access(const char *path, int mask);
 
 #endif /* __LXCFS_SYSFS_FUSE_H */
